/*
 * This file is a part of VyQChat.
 *
 * Copyright (C) 2002-2003 Pawel Stolowski <yogin@linux.bydg.org>
 *
 * VyQChat is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#ifndef __APPWIN_H
#define __APPWIN_H

#include <qmainwindow.h>
#include <qstringlist.h>
#include <qregexp.h>
#include "global.h"

class ChannelList;
class Settings;
class User;
class UsersList;
class ChatTab;
class ChatLine;
class VySendSocket;
class VyGetSocket;
class VyPacket;
class History;
class QMenuBar;
class QSocketNotifier;
class QComboBox;

class MainWindow: public QMainWindow
{
	Q_OBJECT
	private:
		QMenuBar *main_menu;
		QComboBox *status_combo;
		ChatLine *chatline;
		ChatTab *chattab;
		UsersList *userslist;
		VySendSocket *sockout;
		VyGetSocket *sockin;
		QSocketNotifier *socknotify;
		static const QString MAIN_CH;
		//
		// current options and status
		ChannelList *availchannels;
		History *dnd_list;
		History *away_list;
		History *offline_list;
		History *regexp_list;
		Settings *settings;
		QString nick;
		QString autoanswer;
		QColor special_color;
		QColor normal_color;
		QColor own_color;
		QRegExp regexp;
		bool regexp_on;
		char status;
		char winstate;
		char gender;
		char remoteactive;

		bool parse(QString &str);
		void action(const VyPacket &vp);
		void startChat();

	private slots:
		void openSendMessage(const QString &to);
		void openSendMassMessage(const QStringList &nicks);
		void sendMessage(const QString &to, const QString &msg);
		void sendMassMessage(const QStringList &nicks, const QString &msg);
		void requestInfo(const QString &who);
		void joinChannel(const QString &channel);
		void beep(const QString &who);
		void openPrivate(const QString &who);
		void sendLine();
		void slotDataReceived();
		void slotMenuExit();
		void forceRefresh();
		void slotMenuDummy();
		void openTopicDialog();
		void openSettingsDialog();
		void goNORMAL();
		void goDND(const QString &txt);
		void goAWAY(const QString &txt);
		void goOFFLINE(const QString &txt);
		void openRegexpDialog();
		void openDNDdialog();
		void openAWAYdialog();
		void openOFFLINEdialog();
		void newTopic(const QString &channel, const QString &txt);
		void slotChangeRegexp(const QString &txt, bool on);
		void slotStatusComboActivated(int item);
		void usersListUpdate();
		void popupAbout();
		void openChannelsDialog();
		void commandMenuAction(int option);

	public:
		//
		// IDs for command menu items
		enum {
			ID_ENTER_ME = ID_COMMAND_MENU,
			ID_ENTER_NICK,
			ID_ENTER_JOIN,
			ID_ENTER_LEAVE,
			ID_ENTER_CHAT,
			ID_ENTER_TOPIC,
			ID_ENTER_INFO,
			ID_ENTER_BEEP,
			ID_ENTER_MASS,
			ID_ENTER_HERE,
			ID_ENTER_NORMAL,
			ID_ENTER_DND,
			ID_ENTER_AWAY,
			ID_ENTER_OFFLINE,
			ID_ENTER_HELP
		};

		MainWindow();
		~MainWindow();
};

#endif

