/*
 * This file is a part of VyQChat.
 *
 * Copyright (C) 2002-2003 Pawel Stolowski <yogin@linux.bydg.org>
 *
 * VyQChat is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#include "chattab.h"
#include "icons.h"

ChatTab::ChatTab(QWidget *parent): QTabWidget(parent)/*{{{*/
{
	setFocusPolicy(QWidget::NoFocus);
}/*}}}*/

ChatTab::~ChatTab()/*{{{*/
{
}/*}}}*/

bool ChatTab::isPrivate(const QString &name)/*{{{*/
{
	ChannelMap::iterator it = cmap.find(name);
	return (it!=cmap.end()) ? it.data()->isPrivate() : false;
} /*}}}*/

bool ChatTab::addChannel(const QString &name, const QString &topic) /*{{{*/
{
	QString n = (name[0]=='#') ?  name : "#" + name;

	if (exists(n))
		return false;
	Channel *c = new Channel(this, n, topic);
	addTab(c, Icons::icon_channel, n);
	cmap[n] = c;
	showPage(c);
	return true;
} /*}}}*/

bool ChatTab::delChannel(const QString &name)/*{{{*/
{
	QString n = (name[0]=='#') ?  name : "#" + name;

	ChannelMap::iterator it = cmap.find(n);
	if (it != cmap.end())
	{
		removePage(it.data());
		delete it.data();
		cmap.remove(it);
		return true;
	}
	return false;
}/*}}}*/

bool ChatTab::addPrivate(const QString &name)/*{{{*/
{
	const QString &n = name;
	
	if (exists(n))
		return false;

	Channel *c = new Channel(this, n, true);
	addTab(c, Icons::icon_private, n);
	cmap[n] = c;
	showPage(c);
	return true;
}/*}}}*/

bool ChatTab::delPrivate(const QString &name)/*{{{*/
{
	const QString &n = name;

	ChannelMap::iterator it = cmap.find(n);
	if (it != cmap.end())
	{
		removePage(it.data());
		delete it.data();
		cmap.remove(it);
		return true;
	}
	return false;
}/*}}}*/

QString ChatTab::getTopic(const QString &name)/*{{{*/
{
	ChannelMap::iterator it = cmap.find(name);
	return (it == cmap.end()) ? QString::null : it.data()->getTopic();
}/*}}}*/

bool ChatTab::setTopic(const QString &name, const QString &topic)/*{{{*/
{
	ChannelMap::iterator it = cmap.find(name);
	if (it != cmap.end())
	{
		it.data()->setTopic(topic);
		return true;
	}
	return false;
}/*}}}*/

bool ChatTab::write(const QString &channel, const QString &str, QColor color)/*{{{*/
{
	ChannelMap::iterator it = cmap.find(channel);
	if (it != cmap.end())
	{
		it.data()->setColor(color);
		it.data()->append(str);
		return true;
	}
	return false;
}/*}}}*/

void ChatTab::slotClearCurrent()/*{{{*/
{
	currentPage()->clear();
}/*}}}*/

QString ChatTab::channelsList()/*{{{*/
{
	QString list;
	for (ChannelMap::iterator it = cmap.begin(); it != cmap.end(); it++ )
		if (! it.data()->isPrivate())
			list += it.data()->name();
	return list;
}/*}}}*/

